@@ -1,4 +1,4 @@
-#[derive(Default,Debug)]
+#[derive(Debug)]
 #[derive(serde_derive::Deserialize,serde_derive::Serialize)]
 struct Serialized {
 	#[serde(rename="s")]
